@@ -101,6 +101,9 @@ pub struct Client {
     /// If None, then unauthenticated requests are made.
     credentials: Option<hawk::Credentials>,
 
+    /// The root URL used to configure this client
+    root_url: String,
+
     /// The `ext` string for any requests made by this client, if any
     ext: Option<String>,
 
@@ -200,10 +203,13 @@ impl Client {
             }),
         };
 
+        let root_url = b.root_url;
+
         Ok(Client {
             credentials,
             ext,
             retry,
+            root_url,
             base_url,
             host,
             port,
@@ -288,6 +294,11 @@ impl Client {
         }
     }
 
+    /// Get the root URL with which this client was configured
+    pub fn root_url(&self) -> &str {
+        self.root_url.as_ref()
+    }
+
     fn build_request(
         &self,
         method: &str,
@@ -307,7 +318,14 @@ impl Client {
 
         let meth = reqwest::Method::from_str(method)?;
 
-        let req = self.client.request(meth, url);
+        let mut req = self.client.request(meth, url);
+
+        // pass content-length: 0 if there is no body.  This is implicit for GET requests,
+        // but not for methods that typically have a body.  Most other HTTP clients do this
+        // automatically!
+        if body.is_none() {
+            req = req.header("Content-Length", "0");
+        }
 
         let req = match body {
             Some(b) => req.json(&b),
